unit about;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ExtMsgDlg, Misc, Buttons;

type
  TAboutForm = class(TForm)
    ProgramIcon: TImage;
    ProductLabel: TLabel;
    CopyrightLabel: TLabel;
    VersionLabel: TLabel;
    CommentLabel: TLabel;
    URLLabel: TLabel;
    OKBtn: TBitBtn;
    LicenseLabel: TLabel;
    LicenseUrlLabel: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure URLLabelClick(Sender: TObject);
    procedure LicenseUrlLabelClick(Sender: TObject);
  private
    { Private declarations }
    fLicenseUrl: String;
    procedure SetProduct(S: String);
    procedure SetCopyright(S: String);
    procedure SetVersion(S: String);
    procedure SetComment(S: String);
    procedure SetURL(URL: String);
    function GetURL: string;
    procedure SetLicenseCaption(S: String);
    procedure SetLicenseName(S: String);
    function GetLicenseURL: String;
    procedure SetLicenseURL(S: String);
  public
    { Public declarations }
    Property ProductName: String write SetProduct;
    Property Copyright: String write SetCopyright;
    Property Version: String write SetVersion;
    Property Comment: String write SetComment;
    Property URL: String read GetUrl write SetUrl;
    Property LicenseCaption: String write SetLicenseCaption;
    Property LicenseName: String write SetLicensename;
    property LicenseURL: String read GetLicenseURL write SetLicenseURL;
  end;

var
  AboutForm: TAboutForm;

procedure AboutDlg(const ATitle, AProductName, AVersion,
                  ACopyright, AURL, AComment: String);

procedure AboutDlgEx(const ATitle, AProductName, AVersion,
                    ACopyright, AURL, ALicenseCaption,
                    ALicenseName, ALicenseUrl, AComment: String);

implementation

{$R *.DFM}

procedure TAboutForm.FormCreate(Sender: TObject);
begin
  ProgramIcon.Picture.Graphic := Application.Icon;
  fLicenseUrl := '';
end;



procedure TAboutForm.SetProduct(S: String);
begin
  ProductLabel.Caption := S;
end;

procedure TAboutForm.SetCopyright(S: String);
begin
  CopyrightLabel.Caption := S;
end;

procedure TAboutForm.SetVersion(S: String);
begin
  VersionLabel.Caption := S;
end;

procedure TAboutForm.SetComment(S: String);
begin
  CommentLabel.Caption := S;
end;


procedure TaboutForm.SetURL(URL: String);
begin
  URLLabel.Caption := URL;
  if URL = '' then URLLabel.Visible := False
  else URLLabel.Visible := True;
end;

function TAboutForm.GetURL: string;
begin
  Result := URLLabel.Caption;
end;

procedure TAboutForm.SetLicenseCaption(S: String);
begin
  LicenseLabel.Caption := S;
  LicenseLabel.Visible := (S <> '');
end;


procedure TAboutForm.SetLicenseName(S: String);
begin
  LicenseUrlLabel.Caption := S;
  LicenseUrlLabel.Visible := (S <> '')
end;


function TAboutForm.GetLicenseURL: String;
begin
  Result := fLicenseURL;
end;


procedure TAboutForm.SetLicenseURL(S: String);
begin
  fLicenseURL := S;
  if S = '' then
  begin
    LicenseUrlLabel.Font.Style := [];
    LicenseUrlLabel.Cursor := crDefault;
  end;
end;


procedure AboutDlgEx(const ATitle, AProductName, AVersion,
                    ACopyright, AURL, ALicenseCaption,
                    ALicenseName, ALicenseUrl, AComment: String);
var XY: Integer;
begin
  XY := GetSystemMetrics(SM_CYCAPTION) + GetSystemMetrics(SM_CYFRAME);
  //XY := Application.MainForm.Height - Application.MainForm.ClientHeight;
  //if XY < GetSystemMetrics(SM_CYCAPTION) then XY := GetSystemMetrics(SM_CYCAPTION);
  AboutForm := TAboutForm.Create(Application);
  try
    with AboutForm do
    begin
      if (ATitle = '') then Caption := 'Info' else Caption := ATitle;
      if (AProductName = '') then ProductName := Application.Title
        else ProductName := AProductName;
      LicenseCaption := ALicenseCaption;
      LicenseName := ALicenseName;
      LicenseUrl := ALicenseUrl;
      Version := AVersion;
      CopyRight := ACopyright;
      Comment := AComment;
      URL := AURL;

      if not LicenseLabel.Visible then
      begin
        CommentLabel.Top := LicenseUrlLabel.Top;
        LicenseUrlLabel.Top := LicenseLabel.Top;
      end;

      if not LicenseUrlLabel.Visible then
        CommentLabel.Top := LicenseUrlLabel.Top;

      OkBtn.Top := CommentLabel.Top + CommentLabel.Height + 11;
      AboutForm.ClientHeight := OkBtn.Top + OkBtn.Height + 11;

      AboutForm.Left := Application.MainForm.Left + XY;
      AboutForm.Top := Application.MainForm.Top + XY;
      ShowModal;
    end;
  finally
    AboutForm.Free;
  end;
end;

procedure AboutDlg(const ATitle, AProductName, AVersion,
                  ACopyright, AURL, AComment: String);
begin
  AboutDlgEx(ATitle, AProductName, AVersion,
             ACopyright, AURL, '','','', AComment)
end;

procedure TAboutForm.URLLabelClick(Sender: TObject);
begin
  if URL <> '' then
  begin
    if not ExecuteFile(URL) then
     //MessageDlg('Fout bij openen van "'+ URL + '"',mtError,[mbOk],0);
  end;
end;

procedure TAboutForm.LicenseUrlLabelClick(Sender: TObject);
begin
  if fLicenseUrl <> '' then
  begin
    if not ExecuteFile(fLicenseUrl) then
      //MessageDlg('Fout bij openen van "'+ fLicenseUrl + '"',mtError,[mbOk],0);
  end;
end;

end.
