unit ExtMsgDlg;

interface

uses SysUtils, WinTypes, WinProcs, Messages, Classes,
     Graphics, Controls, Forms, Dialogs, StdCtrls,
     ExtCtrls, Buttons;


type TMsgDlgLanguage = (langDefault, langNL);

var MsgDlgLanguage: TMsgDlgLanguage;
    CenterDialogsOverMainForm: Boolean;

    
Function MessageDlgPos(const Msg: String;
           AType: TMsgDlgType; Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer): TModalResult;

Function MessageDlg(const Msg: String;
           AType: TMsgDlgType; Buttons: TMsgDlgButtons;
           HelpCtx: LongInt): TModalResult;

Function ExtMessageDlg(const Msg: String;
           AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;

Function ExtMessageDlgPos(const Msg: String;
           AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;

Function ExtCustomMessageDlg(const Msg: String;
           const Title: String; AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer;
           ALang: TMsgDlgLanguage;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;




implementation



function TranslateDlgCaptionByType(const AType: TMsgDlgType; ALang: TMsgDlgLanguage): String;
begin
  Case AType of
    mtWarning:
    begin
      Case ALang of
        langDefault: Result := 'Warning';
        langNL: Result := 'Waarschuwing';
      end;//Case ALang
    end;
    mtInformation:
    begin
      Case ALang of
        langDefault: Result := 'Information';
        langNL: Result := 'Informatie';
      end;//Case ALang
    end;
    mtError:
    begin
      Case ALang of
        langDefault: Result := 'Error';
        langNL: Result := 'Fout';
      end;//Case ALang
    end;
    mtConfirmation:
    begin
      Case ALang of
        langDefault: Result := 'Confirmation';
        langNL: Result := 'Bevestiging';
      end;//Case ALang
    end;
  end;//Case AType
end;


function TranslateButtonCaptionByModalResult(const AModalResult: TModalResult; ALang: TMsgDlgLanguage): String;
begin
  Case AModalresult of
    mrOK:
    begin
      Case ALang of
        langNL: Result := 'OK';
      end;//Case ALang
    end;
    mrCancel:
    begin
      Case ALang of
        langNL: Result := '&Annuleer';
      end;//Case ALang
    end;
    mrAbort:
    begin
      Case ALang of
        langNL: Result := 'Af&breken';
      end;//Case ALang
    end;
    mrRetry:
    begin
      Case ALang of
        langNL: Result := '&Opnieuw';
      end;//Case ALang
    end;
    mrIgnore:
    begin
      Case ALang of
        langNL: Result := 'Over&slaan';
      end;//Case ALang
    end;
    mrYes:
    begin
      Case ALang of
        langNL: Result := '&Ja';
      end;//Case ALang
    end;
    mrNo:
    begin
      Case ALang of
        langNL: Result := '&Nee';
      end;//Case ALang
    end;
    mrAll:
    begin
      Case ALang of
        langNL: Result := 'A&lle(n)';
      end;//Case ALang
    end;
    mrYesToAll:
    begin
      Case ALang of
        langNL: Result := 'Ja o&p alles';
      end;//Case ALang
    end;
    mrNoToAll:
    begin
      Case ALang of
        langNL: Result := 'N&ee op alles';
      end;//Case ALang
    end;
  End;//Case AModalResult
end;


function TranslateHelpButton(ALang: TMsgDlgLanguage): String;
begin
  Case ALang of
    langNl: Result := '&Help';
  End;//Case AModalResult
end;



function CreateExtMessageDlg(const Msg: String;
           const Title: String; AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer;
           ALang: TMsgDlgLanguage;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TForm;
var i: Integer;
    ATop, ALeft, AWidth, AHeight: Integer;
    CB: TCheckBox;
const CBSpacer = 8;
begin

//  Result := CreateMessageDialog(Msg+^m'HelpContext = '+IntToStr(HelpCtx),TMsgDlgType(AType),TMsgDlgButtons(Buttons));


  Result := CreateMessageDialog(Msg,TMsgDlgType(AType),TMsgDlgButtons(Buttons));
  with Result do
  begin{with}
    //Anders functioneert Helpbutton (en F1) niet
    HelpContext := HelpCtx;

    if (Title = EmptyStr) then Caption := TranslateDlgCaptionByType(AType, ALang)
    else Caption := Title;
    if X > -1 then Left := X;
    if Y > -1 then Top := Y;
    ScaleBy(Screen.PixelsPerInch,96);

    if (ALang <> langDefault) then for i := 0 to ControlCount-1 do if Controls[i] is TButton then
    //Vertaal Button captions
    begin{for}
      if (TButton(Controls[i]).ModalResult <> mrNone) then
         TButton(Controls[i]).Caption := TranslateButtonCaptionByModalResult(TButton(Controls[i]).ModalResult, ALang)//'&Ja';
      else
        if (Pos('Help',TButton(Controls[i]).caption) > 0) then TButton(Controls[i]).Caption := TranslateHelpButton(ALang);
    end;{for}


    if (DefButton <> mrNone) then for i := 0 to ControlCount-1 do if Controls[i] is TButton then
    //Zoek default button
    begin{for}
      if (TButton(Controls[i]).ModalResult = DefButton) then
      begin
        TButton(Controls[i]).Default := True;
        ActiveControl := TButton(Controls[i]);
        Break;
      end;
    end;{for}

(*
    for i := 0 to ControlCount-1 do if Controls[i] is TButton then
    begin
      if (Pos('Help',TButton(Controls[i]).caption) > 0) then
      begin
        TButton(Controls[i]).OnClick := TMessageForm(Result).HelpButtonClick;
      end;
    end;
*)

    if HasCheckBox then
    begin
      CB := TCheckBox.Create(Result);
      CB.Parent := Result;
      CB.Checked := False;
      CB.Left := CBSpacer;
      CB.Width := Result.ClientWidth - CBSpacer;
      Result.Height := Result.Height + CBSpacer + CB.Height;
      CB.Top := Result.ClientHeight - CB.Height - CBSpacer;
      CB.Caption := ACheckBoxCaption;
    end;

    if CenterDialogsOverMainForm and (X < 0) and (Y < 0) and (Application.MainForm <> nil) then
    begin//Centreer dialoog t.o.v. mainForm, niet t.o.v. Screen
      ATop := Application.MainForm.Top;
      ALeft := Application.MainForm.Left;
      AHeight := Application.MainForm.Height;
      AWidth := Application.MainForm.Width;
      Top := ATop + (AHeight - Height) div 2;
      Left := ALeft + (AWidth - Width) div 2;
      //Houdt dialoog zichtbaar
      if Left + Width > Screen.Width then Left := Screen.Width - Width;
      if Top + Height > Screen.Height then Top := Screen.Height - Height;
      if Left < 0 then Left := 0;
      if Top < 0 then Top := 0;
    end;
  end{with Result}
end;



Function MessageDlgPos(const Msg: String;
           AType: TMsgDlgType; Buttons: TMsgDlgButtons;
           HelpCtx: LongInt; X,Y: Integer): TModalResult;
var Dlg: TForm;
    CBChecked: Boolean;
begin
  Dlg := CreateExtMessageDlg(Msg, EmptyStr, AType, Buttons, HelpCtx, X, Y, MsgDlgLanguage, mrNone, False, EmptyStr, CBChecked);
  Result := Dlg.ShowModal;
  Dlg.Free;
end;

Function MessageDlg(const Msg: String;
           AType: TMsgDlgType; Buttons: TMsgDlgButtons;
           HelpCtx: LongInt): TModalResult;
begin
  Result := MessageDlgPos(Msg,AType,Buttons,HelpCtx,-1,-1);
end;


Function ExtMessageDlg(const Msg: String;
           AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;
begin
  Result := ExtMessageDlgPos(Msg, AType, Buttons, HelpCtx, -1, -1, DefButton, HasCheckBox, ACheckBoxCaption, CheckBoxResult);
end;

Function ExtMessageDlgPos(const Msg: String;
           AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;
var Dlg: TForm;
    i: Integer;
begin
  Dlg := CreateExtMessageDlg(Msg, EmptyStr, AType, Buttons, HelpCtx, X, Y, MsgDlgLanguage, DefButton, HasCheckBox, ACheckBoxCaption, CheckBoxResult);
  Result := Dlg.ShowModal;
  CheckBoxResult := False;
  if HasCheckBox then for i := 0 to Dlg.ControlCount-1 do if Dlg.Controls[i] is TCheckBox then
  begin
    CheckBoxResult := TCheckBox(Dlg.Controls[i]).Checked;
    Break;
  end;
  Dlg.Free;
end;

Function ExtCustomMessageDlg(const Msg: String;
           const Title: String; AType: TMsgDlgType;
           Buttons: TMsgDlgButtons; HelpCtx: LongInt;
           X,Y: Integer;
           ALang: TMsgDlgLanguage;
           DefButton: TModalResult;
           HasCheckBox: Boolean;
           const ACheckBoxCaption: String;
           var CheckBoxResult: Boolean): TModalResult;
var Dlg: TForm;
    i: Integer;
begin
  Dlg := CreateExtMessageDlg(Msg, Title, AType, Buttons, HelpCtx, X, Y, ALang, DefButton, HasCheckBox, ACheckBoxCaption, CheckBoxResult);
  Result := Dlg.ShowModal;
  CheckBoxResult := False;
  if HasCheckBox then for i := 0 to Dlg.ControlCount-1 do if Dlg.Controls[i] is TCheckBox then
  begin
    CheckBoxResult := TCheckBox(Dlg.Controls[i]).Checked;
    Break;
  end;
  Dlg.Free;
end;




Initialization
  CenterDialogsOverMainForm := True;
  MsgDlgLanguage := langNL;
end.


(*
type
  TMessageForm = class(TForm)
  private
    procedure HelpButtonClick(Sender: TObject);
  public
//    constructor CreateNew(AOwner: TComponent);
  end;

constructor TMessageForm.CreateNew(AOwner: TComponent);
var
  NonClientMetrics: TNonClientMetrics;
begin
  inherited CreateNew(AOwner);
  NonClientMetrics.cbSize := sizeof(NonClientMetrics);
  if SystemParametersInfo(SPI_GETNONCLIENTMETRICS, 0, @NonClientMetrics, 0) then
    Font.Handle := CreateFontIndirect(NonClientMetrics.lfMessageFont);
end;

procedure TMessageForm.HelpButtonClick(Sender: TObject);
begin
//  Application.HelpContext(HelpContext);
showmessage('HelpContext := '+IntToStr(HelpContext));
end;
*)

