unit uhelp;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ExtCtrls;


type ThlpSection = (scNone, scRules, scPlay);

type
  THelpForm = class(TForm)
    BtnPanel: TPanel;
    RulesBtn: TButton;
    Memo: TMemo;
    PlayBtn: TButton;
    CloseBtn: TBitBtn;
    Header: TEdit;
    procedure FormShow(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure PlayBtnClick(Sender: TObject);
    procedure CloseBtnClick(Sender: TObject);
    procedure LoadHelpFile(const Section: ThlpSection; const IgnoreErrors: Boolean);
    procedure RulesBtnClick(Sender: TObject);
  private
    { Private declarations }
    fSection: ThlpSection;
  public
    { Public declarations }
  end;

var
  HelpForm: THelpForm;

implementation

{$R *.DFM}

uses Globals, ExtMsgDlg, fpc4delphi;

const msgErrorHelpFile = 'Fout bij  het openen van het helpbestand:'^m^m'%s';
      msgErrorHelpFileMemoText = 'Fout bij  het openen van het helpbestand:'+LineEnding+LineEnding+'  %s';
      RulesHeaderText = 'Hoe het spel in elkaar zit';
      PlayHeaderText = 'Hoe het spel gespeeld wordt';

procedure THelpForm.FormShow(Sender: TObject);
var ALeft, ATop: Integer;
begin
  ALeft := Screen.Width - Width;
  ATop := (Screen.Height - Height) div 2;
  if ALeft < 0 then ALeft := 0;
  if ATop < 0 then ATop := 0;
  SetBounds(ALeft, ATop, Width, Height);
end;

procedure THelpForm.FormCreate(Sender: TObject);
begin
  Header.Align := alTop;
  Memo.Align := alClient;
  LoadHelpFile(scRules, True);

end;

procedure THelpForm.RulesBtnClick(Sender: TObject);
begin
  if (fSection <> scRules) then LoadHelpFile(scRules, False);
end;

procedure THelpForm.PlayBtnClick(Sender: TObject);
begin
  if (fSection <> scPlay) then LoadHelpFile(scPlay, False);
end;

procedure THelpForm.CloseBtnClick(Sender: TObject);
begin
  Close;
end;

procedure THelpForm.LoadHelpFile(const Section: ThlpSection; const IgnoreErrors: Boolean);
var Fn, HeaderText: String;
begin
  if Section = scNone then Exit;
  Case Section of
    scRules:
    begin
      Fn := ExtractFilePath(ParamStr(0)) + RulesFileName;
      HeaderText := RulesHeaderText;
    end;
    scPlay:
    begin
      Fn := ExtractFilePath(ParamStr(0)) + PlayFileName;
      HeaderText := PlayHeaderText;
    end;
    else exit;
  end;
  Header.Text := HeaderText;
  try
    Memo.Lines.LoadFromFile(Fn);
  Except
    if not IgnoreErrors then MessageDlg(Format(msgErrorHelpFile,[Fn]), mtError, [mbOk], 0)
    else Memo.Text := Format(msgErrorHelpFileMemoText,[Fn]);
  end;
  fSection := Section;
end;


end.
