unit uoptionsdlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ComCtrls, Spin, ExtCtrls;

type
  TOptionsDlg = class(TForm)
    OkBtn: TBitBtn;
    CancelBtn: TBitBtn;
    SpeedGroupBox: TGroupBox;
    SpeedTrackbar: TTrackBar;
    StaticText1: TStaticText;
    StaticText2: TStaticText;
    LifeSizeGroupBox: TGroupBox;
    StaticText3: TStaticText;
    StaticText4: TStaticText;
    LifeXEdit: TSpinEdit;
    LifeYEdit: TSpinEdit;
    CellSizeGroupBox: TGroupBox;
    CellXEdit: TSpinEdit;
    CellYEdit: TSpinEdit;
    Hrizontaal: TStaticText;
    Verticaal: TStaticText;
    WrapGroupBox: TRadioGroup;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure CellEditChange(Sender: TObject);
  private
    { Private declarations }
    fLifeX, fLifeY, fCellX, fCellY, fTimerInterval: Integer;
    fWrapStyle: Integer;
    procedure SetLifeX(const Value: Integer);
    procedure SetLifeY(const Value: Integer);
    procedure SetCellX(const Value: Integer);
    procedure SetCellY(const Value: Integer);
    procedure SetWrapStyle(const Value: Integer);
    procedure SetTimerInterval(Value: Integer);
    function GetLifeX: Integer;
    function GetLifeY: Integer;
    function GetCellX: Integer;
    function GetCellY: Integer;
    function GetWrapStyle: Integer;
    function GetTimerInterval: Integer;
  public
    { Public declarations }
    property optLifeX: Integer read GetLifeX write SetLifeX;
    property optLifeY: Integer read GetLifeY write SetLifeY;
    property optCellX: Integer read GetCellX write SetCellX;
    property optCellY: Integer read GetCellY write SetCellY;
    property optWrapStyle: Integer read GetWrapStyle write SetWrapStyle;
    property optTimerInterval: Integer read GetTimerInterval write SetTimerInterval;
  end;

var
  OptionsDlg: TOptionsDlg;

function LimitTo(AValue: LongInt; const LowerLimit, UpperLimit: LongInt): LongInt;

implementation

{$R *.DFM}

uses Globals, fpc4delphi;

function LimitTo(AValue: LongInt; const LowerLimit, UpperLimit: LongInt): LongInt;
begin
  if (AValue < LowerLimit) then AValue := LowerLimit else
  if (AValue > UpperLimit) then AValue := UpperLimit;
  Result := AValue;
end;

procedure TOptionsDlg.SetLifeX(const Value: Integer);
begin
  fLifeX := LimitTo(Value, MinLifeX, MaxLifeX);
  LifeXEdit.Value := fLifeX;
end;


procedure TOptionsDlg.SetLifeY(const Value: Integer);
begin
  fLifeY := LimitTo(Value, MinLifeY, MaxLifeY);
  LifeYEdit.Value := fLifeY;
end;

procedure TOptionsDlg.SetCellX(const Value: Integer);
begin
  fCellX := LimitTo(Value, MinCellX, MaxCellX);
  CellXEdit.Value := fCellX;
end;

procedure TOptionsDlg.SetCellY(const Value: Integer);
begin
  fCellY := LimitTo(Value, MinCellY, MaxCellY);
  CellYEdit.Value := fCellY;
end;

procedure TOptionsDlg.SetWrapStyle(const Value: Integer);
begin
  fWrapStyle := LimitTo(Value, wrNone, wrBoth);
  WrapGroupBox.ItemIndex := fWrapStyle;
end;

procedure TOptionsDlg.SetTimerInterval(Value: Integer);
begin
  Value := LimitTo(Value, TimerIntervalFastest, TimerIntervalSlowest);
  case Value of
    TimerIntervalFastest: begin SpeedTrackBar.Position := 5; end;
    TimerIntervalFaster:  begin SpeedTrackBar.Position := 4; end;
    TimerIntervalAverage: begin SpeedTrackBar.Position := 3; end;
    TimerIntervalSlower:  begin SpeedTrackBar.Position := 2; end;
    TimerIntervalSlowest: begin SpeedTrackBar.Position := 1; end;
    else begin SpeedTrackBar.Position := 3; Value := TimerIntervalAverage; end;
  end;
  fTimerInterval := Value;
end;


function TOptionsDlg.GetLifeX: Integer;
begin
  Result := LimitTo(LifeXEdit.Value, MinLifeX, MaxLifeX);
end;


function TOptionsDlg.GetLifeY: Integer;
begin
  Result := LimitTo(LifeYEdit.Value, MinLifeY, MaxLifeY);
end;

function TOptionsDlg.GetCellX: Integer;
begin
  Result := LimitTo(CellXEdit.Value, MinCellX, MaxCellX);
end;

function TOptionsDlg.GetCellY: Integer;
begin
  Result := LimitTo(CellYEdit.Value, MinCellY, MaxCellY);
end;

function TOptionsDlg.GetWrapStyle: Integer;
begin
  Result := LimitTo(WrapGroupBox.ItemIndex, wrNone, wrBoth);
end;

function TOptionsDlg.GetTimerInterval: Integer;
var Value: Integer;
begin
  Value := LimitTo(SpeedtrackBar.Position, 1, 5);
  Case Value of
    1: Result := TimerIntervalSlowest;
    2: Result := TimerIntervalSlower;
    3: Result := TimerIntervalAverage;
    4: Result := TimerIntervalFaster;
    5: Result := TimerIntervalFastest;
  end;
end;


procedure TOptionsDlg.FormCreate(Sender: TObject);
begin
  LifeXEdit.MinValue := MinLifeX;
  LifeXEdit.MaxValue := MaxLifeX;
  LifeYEdit.MinValue := MinLifeY;
  LifeYEdit.MaxValue := MaxLifeY;
  CellXEdit.MinValue := MinCellX;
  CellXEdit.MaxValue := MaxCellX;
  CellYEdit.MinValue := MinCellY;
  CellYEdit.MaxValue := MaxCellY;
 {$IFDEF HUGE_WORLD}
 //X en Y grootte zelfde houden in deze configuratie
 CellXEdit.OnChange := CellEditChange;
 CellYEdit.OnChange := CellEditChange;
 {$ENDIF}
end;

procedure TOptionsDlg.FormShow(Sender: TObject);
begin
  ActiveControl := SpeedTrackBar;
end;

procedure TOptionsDlg.CellEditChange(Sender: TObject);
begin
  With (Sender as TSpinEdit) do
  begin
    CellXEdit.Value := Value;
    CellYEdit.Value := Value;
  end;
end;

end.
